# Generated by roxygen2: do not edit by hand

S3method(drawDetails,acpoint)
S3method(ggplot,acmap)
S3method(plot,acmap)
S3method(postDrawDetails,acpoint)
S3method(preDrawDetails,acpoint)
S3method(print,Rac_html_merge_report)
S3method(print,acmap)
S3method(view,acmap)
S3method(view,default)
export("agAnnotations<-")
export("agAspect<-")
export("agBaseCoords<-")
export("agClades<-")
export("agContinent<-")
export("agCoords<-")
export("agDates<-")
export("agExtra<-")
export("agFill<-")
export("agGroups<-")
export("agIDs<-")
export("agLabIDs<-")
export("agLineage<-")
export("agNames<-")
export("agNucleotideSequences<-")
export("agOpacity<-")
export("agOutline<-")
export("agOutlineWidth<-")
export("agPassage<-")
export("agReactivityAdjustments<-")
export("agReassortant<-")
export("agReference<-")
export("agRotation<-")
export("agSequences<-")
export("agShape<-")
export("agShown<-")
export("agSize<-")
export("agStrings<-")
export("dilutionStepsize<-")
export("fixedColBases<-")
export("layerNames<-")
export("mapComment<-")
export("mapDescription<-")
export("mapName<-")
export("mapTransformation<-")
export("mapTranslation<-")
export("minColBasis<-")
export("ptCoords<-")
export("ptDrawingOrder<-")
export("srAnnotations<-")
export("srAspect<-")
export("srBaseCoords<-")
export("srClades<-")
export("srCoords<-")
export("srDates<-")
export("srExtra<-")
export("srFill<-")
export("srGroups<-")
export("srHomologousAgs<-")
export("srIDs<-")
export("srLineage<-")
export("srNames<-")
export("srNucleotideSequences<-")
export("srOpacity<-")
export("srOutline<-")
export("srOutlineWidth<-")
export("srPassage<-")
export("srReassortant<-")
export("srReference<-")
export("srRotation<-")
export("srSequences<-")
export("srShape<-")
export("srShown<-")
export("srSize<-")
export("srSpecies<-")
export("srStrings<-")
export("titerTable<-")
export(RacMerge.options)
export(RacOptimizer.options)
export(RacViewer)
export(RacViewer.options)
export(RacViewerOutput)
export(acmap)
export(addOptimization)
export(adjustedLogTiterTable)
export(adjustedTiterTable)
export(agAnnotations)
export(agAspect)
export(agBaseCoords)
export(agBootstrapBlob)
export(agBootstrapBlobs)
export(agBootstrapCoords)
export(agClades)
export(agCohesion)
export(agContinent)
export(agCoords)
export(agDates)
export(agExtra)
export(agFill)
export(agGroups)
export(agHomologousSr)
export(agIDs)
export(agLabIDs)
export(agLeverage)
export(agLineage)
export(agNames)
export(agNucleotideSequences)
export(agOutline)
export(agOutlineWidth)
export(agPassage)
export(agReactivityAdjustments)
export(agReassortant)
export(agReference)
export(agRotation)
export(agSequences)
export(agShape)
export(agShown)
export(agSize)
export(agStress)
export(agStressPerTiter)
export(agStrings)
export(agTriangulationBlob)
export(agTriangulationBlobs)
export(allMapDimensions)
export(allMapStresses)
export(applyMapTransform)
export(applyPlotspec)
export(as.json)
export(blob)
export(blobsize)
export(bootstrapBlobs)
export(bootstrapMap)
export(checkHemisphering)
export(colBases)
export(dilutionStepsize)
export(dimensionTestMap)
export(edit_agNames)
export(edit_srNames)
export(export_viewer)
export(fixedColBases)
export(getOptimization)
export(htmlAdjustedTiterTable)
export(htmlMergeReport)
export(htmlTiterTable)
export(keepBestOptimization)
export(keepOptimizations)
export(keepSingleOptimization)
export(layerNames)
export(listOptimizations)
export(logtiterTable)
export(logtiterTableLayers)
export(make.acmap)
export(mapBootstrap_agCoords)
export(mapBootstrap_srCoords)
export(mapCohesion)
export(mapComment)
export(mapDescription)
export(mapDimensions)
export(mapDistances)
export(mapGadget)
export(mapName)
export(mapRelaxed)
export(mapResiduals)
export(mapStress)
export(mapTransformation)
export(mapTranslation)
export(match_mapAntigens)
export(match_mapSera)
export(mergeMaps)
export(mergeReport)
export(minColBasis)
export(moveTrappedPoints)
export(numAntigens)
export(numLayers)
export(numOptimizations)
export(numPoints)
export(numSera)
export(numSeraGroups)
export(optimizeAgReactivity)
export(optimizeMap)
export(orderAntigens)
export(orderSera)
export(plot_map_table_distance)
export(plotly_map_table_distance)
export(procrustesData)
export(procrustesMap)
export(ptBaseCoords)
export(ptBootstrapBlobs)
export(ptBootstrapCoords)
export(ptCoords)
export(ptDrawingOrder)
export(ptTriangulationBlobs)
export(randomizeCoords)
export(read.acmap)
export(read.titerTable)
export(realignMap)
export(realignOptimizations)
export(recalculateStress)
export(reflectMap)
export(relaxMap)
export(relaxMapOneStep)
export(removeAntigens)
export(removeOptimizations)
export(removeSera)
export(renderRacViewer)
export(rotateMap)
export(runGUI)
export(save.acmap)
export(save.coords)
export(save.titerTable)
export(setLegend)
export(sortOptimizations)
export(splitTiterLayers)
export(srAnnotations)
export(srAspect)
export(srBaseCoords)
export(srBootstrapBlob)
export(srBootstrapBlobs)
export(srBootstrapCoords)
export(srClades)
export(srCohesion)
export(srCoords)
export(srDates)
export(srExtra)
export(srFill)
export(srGroups)
export(srHomologousAgs)
export(srIDs)
export(srLeverage)
export(srLineage)
export(srNames)
export(srNucleotideSequences)
export(srOutline)
export(srOutlineWidth)
export(srPassage)
export(srReassortant)
export(srReference)
export(srRotation)
export(srSequences)
export(srShape)
export(srShown)
export(srSize)
export(srSpecies)
export(srStress)
export(srStressPerTiter)
export(srStrings)
export(srTriangulationBlob)
export(srTriangulationBlobs)
export(standardizeStrainNames)
export(stressBlobs)
export(stressTable)
export(subsetMap)
export(tableColbases)
export(tableDistances)
export(titerLeverage)
export(titerTable)
export(titerTableLayers)
export(translateMap)
export(triangulationBlobs)
export(update_ferret_seraNames)
export(view)
import(htmlwidgets)
importFrom(Rcpp,`sourceCpp`)
importFrom(ggplot2,`.data`)
importFrom(ggplot2,`ggplot`)
importFrom(grid,`drawDetails`)
importFrom(grid,`postDrawDetails`)
importFrom(grid,`preDrawDetails`)
importFrom(magrittr,`%>%`)
importFrom(rlang,`.data`)
useDynLib(Racmacs)
